@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2018 by Dominique Dumont <ddumont@cpan.org>.
+# This software is Copyright (c) 2008-2019 by Dominique Dumont <ddumont@cpan.org>.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Tk::AnyViewer;
-$Config::Model::Tk::AnyViewer::VERSION = '1.368';
+package Config::Model::Tk::AnyViewer 1.370;
+
 use strict;
 use warnings;
 use Carp;
@@ -224,7 +224,7 @@ sub update_warning {
     my $err = $elt_obj->error_msg || '';
     $ww->insert( 'end', $err, 'error' ) if $err;
 
-    my $msg .= $elt_obj->warning_msg || '';
+    my $msg = $elt_obj->warning_msg || '';
     if ( ref($msg) eq 'HASH' ) {
         $msg = join( '', map { join( "\n\t", @{ $msg->{$_} } ) } sort keys %$msg );
     }
