@@ -1,15 +1,15 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2018 by Dominique Dumont <ddumont@cpan.org>.
+# This software is Copyright (c) 2008-2019 by Dominique Dumont <ddumont@cpan.org>.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 
-package Config::Model::Tk::Wizard;
-$Config::Model::Tk::Wizard::VERSION = '1.368';
+package Config::Model::Tk::Wizard 1.370;
+
 use strict;
 use warnings;
 use Carp;
@@ -233,7 +233,6 @@ sub start_wizard {
         } );
     $forw->pack(qw/-side right -fill x -expand 1/);
 
-    my ( $sort_element, $sort_idx );
     $cw->{keep_wiz_editor} = 1;
 
     my %cb_table;
